/*
 * (C) Copyright 2016 Kurento (http://kurento.org/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.kurento.commons.net;

import java.io.IOException;
import java.net.ConnectException;
import java.net.Socket;
import java.net.UnknownHostException;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.TimeoutException;

public class RemoteService {

  public static void waitForReady(String host, int port, int time, TimeUnit unit)
      throws UnknownHostException, IOException, TimeoutException {

    long maxTime = System.currentTimeMillis() + unit.toMillis(time);

    while (true) {
      try {
        Socket client = new Socket(host, port);
        client.close();
        break;
      } catch (ConnectException ce) {

        if (System.currentTimeMillis() > maxTime) {
          throw new TimeoutException();
        }

        try {
          Thread.sleep(100);
        } catch (InterruptedException e) {
          // Intentionally left blank
        }
      }
    }
  }

}
